<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-images?lang_cible=ja
// ** ne pas modifier le fichier **

return [

	// I
	'images_description' => '画像および色変換フィルタ',
	'images_slogan' => '画像および色変換フィルタ',
];
